@@ -47,7 +47,11 @@
 #include <freerdp/gdi/region.h>
 #include <freerdp/client/cliprdr.h>
 #include <freerdp/client/disp.h>
+#ifdef GDK_WINDOWING_X11
 #include <gdk/gdkx.h>
+#else
+#include <gdk/gdkwayland.h>
+#endif
 
 #include <winpr/clipboard.h>
 
@@ -62,7 +66,6 @@
  *
  * Returns: %TRUE if FREERDP headers are new enough
  */
-
 #define FREERDP_CHECK_VERSION(major,minor,revision)                                  \
 	(FREERDP_VERSION_MAJOR > (major) ||                                       \
 	 (FREERDP_VERSION_MAJOR == (major) && FREERDP_VERSION_MINOR > (minor)) || \
@@ -82,7 +85,9 @@ typedef struct rf_context rfContext;
 
 #define GET_PLUGIN_DATA(gp) (rfContext *)g_object_get_data(G_OBJECT(gp), "plugin-data")
 
-/* Performance Flags, from freerdp source
+/**
+ * Performance Flags, from FreeRDP source
+ *
  * PERF_FLAG_NONE 0x00000000
  * PERF_DISABLE_WALLPAPER 0x00000001
  * PERF_DISABLE_FULLWINDOWDRAG 0x00000002
@@ -103,7 +108,27 @@ typedef struct rf_context rfContext;
 #define DEFAULT_QUALITY_9       0x80
 
 extern RemminaPluginService *remmina_plugin_service;
-#define REMMINA_PLUGIN_DEBUG(fmt, ...) remmina_plugin_service->_remmina_debug(__func__, fmt, ##__VA_ARGS__)
+
+#define REMMINA_PLUGIN_INFO(fmt, ...) \
+		remmina_plugin_service->_remmina_info(__func__, fmt, ##__VA_ARGS__)
+
+#define REMMINA_PLUGIN_MESSAGE(fmt, ...) \
+		remmina_plugin_service->_remmina_message(__func, fmt, ##__VA_ARGS__)
+
+#define REMMINA_PLUGIN_DEBUG(fmt, ...) \
+		remmina_plugin_service->_remmina_debug(__func__, fmt, ##__VA_ARGS__)
+
+#define REMMINA_PLUGIN_WARNING(fmt, ...) \
+		remmina_plugin_service->_remmina_warning(__func__, fmt, ##__VA_ARGS__)
+
+/* This will intentionally crash Remmina */
+#define REMMINA_PLUGIN_ERROR(fmt, ...) \
+		remmina_plugin_service->_remmina_error(__func__, fmt, ##__VA_ARGS__)
+
+#define REMMINA_PLUGIN_CRITICAL(fmt, ...) \
+		remmina_plugin_service->_remmina_critical(__func__, fmt, ##__VA_ARGS__)
+#define REMMINA_PLUGIN_AUDIT(fmt, ...) \
+		remmina_plugin_service->_remmina_audit(__func__, fmt, ##__VA_ARGS__)
 
 struct rf_clipboard {
 	rfContext *		rfi;
@@ -118,6 +143,7 @@ struct rf_clipboard {
 	pthread_cond_t		transfer_clip_cond;
 	enum  { SCDW_NONE, SCDW_BUSY_WAIT, SCDW_ABORTING } srv_clip_data_wait;
 	gpointer		srv_data;
+	pthread_mutex_t	srv_data_mutex;
 
 	UINT32			server_html_format_id;
 
@@ -133,18 +159,22 @@ struct rf_pointer {
 };
 typedef struct rf_pointer rfPointer;
 
+#ifdef RF_BITMAP
 struct rf_bitmap {
 	rdpBitmap		bitmap;
 	Pixmap			pixmap;
 	cairo_surface_t *	surface;
 };
 typedef struct rf_bitmap rfBitmap;
+#endif
 
+#ifdef RF_GLYPH
 struct rf_glyph {
 	rdpGlyph	glyph;
 	Pixmap		pixmap;
 };
 typedef struct rf_glyph rfGlyph;
+#endif
 
 typedef enum {
 	REMMINA_RDP_EVENT_TYPE_SCANCODE,
