@@ -32,14 +32,19 @@
  *
  */
 
+#include <gdk/gdk.h>
+
 #define G_LOG_USE_STRUCTURED
 #ifndef G_LOG_DOMAIN
 #define G_LOG_DOMAIN    ((gchar*)"remmina")
 #endif  /* G_LOG_DOMAIN */
+#ifdef GDK_WINDOWING_X11
 #include <gdk/gdkx.h>
+#else
+#include <gdk/gdkwayland.h>
+#endif
 #include <gio/gio.h>
 #include <glib/gi18n.h>
-#include <gtk/gtk.h>
 #include <stdlib.h>
 
 #include "config.h"
@@ -61,7 +66,6 @@
 #include "remmina_ssh_plugin.h"
 #include "remmina_widget_pool.h"
 #include "remmina/remmina_trace_calls.h"
-#include "rmnews.h"
 
 #ifdef HAVE_ERRNO_H
 #include <errno.h>
@@ -81,7 +85,6 @@ static int gcrypt_thread_initialized = 0;
 #endif  /* HAVE_LIBGCRYPT */
 
 gboolean kioskmode;
-gboolean disablenews;
 gboolean disabletoolbar;
 gboolean fullscreen;
 gboolean extrahardening;
@@ -126,7 +129,6 @@ static GOptionEntry remmina_options[] =
 	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
 	{ "set-option",	      0,    0,			  G_OPTION_ARG_STRING_ARRAY,   NULL, N_("Set one or more profile settings, to be used with --update-profile"),		     NULL	},
 	{ "encrypt-password", 0,    0,			  G_OPTION_ARG_NONE,	       NULL, N_("Encrypt a password"),												  NULL		 },
-	{ "disable-news", 0,    0,			  G_OPTION_ARG_NONE,	       NULL, N_("Disable news notification"),												  NULL		 },
 	{ "disable-toolbar", 0,    0,			  G_OPTION_ARG_NONE,	       NULL, N_("Disable toolbar"),												  NULL		 },
 	{ "enable-fullscreen", 0,    0,			  G_OPTION_ARG_NONE,	       NULL, N_("Enable fullscreen"),												  NULL		 },
 	{ "enable-extra-hardening", 0,    0,		  G_OPTION_ARG_NONE,	       NULL, N_("Enable extra hardening (disable closing confirmation, disable unsafe shortcut keys, hide tabs, hide search bar)"),	  NULL		 },
@@ -164,10 +166,6 @@ static gint remmina_on_command_line(GApplication *app, GApplicationCommandLine *
 #endif
 	opts = g_application_command_line_get_options_dict(cmdline);
 
-	if (g_variant_dict_lookup_value(opts, "disable-news", NULL)) {
-		disablenews = TRUE;
-	}
-
 	if (g_variant_dict_lookup_value(opts, "disable-toolbar", NULL)) {
 		disabletoolbar = TRUE;
 	}
@@ -295,8 +293,6 @@ static void remmina_on_startup(GApplication *app)
 					  REMMINA_RUNTIME_DATADIR G_DIR_SEPARATOR_S "icons");
 	g_application_hold(app);
 
-	rmnews_schedule();
-
 	/* Check for secret plugin and service initialization and show console warnings if
 	 * something is missing */
 	secret_plugin = remmina_plugin_manager_get_secret_plugin();
