@@ -42,8 +42,6 @@
 #include <gmodule.h>
 #include <stdlib.h>
 
-
-
 #include "remmina_chat_window.h"
 #include "remmina_masterthread_exec.h"
 #include "remmina_ext_exec.h"
@@ -482,6 +480,8 @@ void remmina_protocol_widget_close_connection(RemminaProtocolWidget *gp)
 		/* Connection is already closed by the plugin, but
 		 * rcw is asking to close again (usually after an error panel)
 		 */
+		/* Clear the current error, or "disconnect" signal func will reshow a panel */
+		remmina_protocol_widget_set_error(gp, NULL);
 		g_signal_emit_by_name(G_OBJECT(gp), "disconnect");
 		return;
 	}
@@ -599,7 +599,7 @@ void remmina_protocol_widget_send_clip_strokes(GtkClipboard *clipboard, const gc
 {
 	TRACE_CALL(__func__);
 	RemminaProtocolWidget *gp = REMMINA_PROTOCOL_WIDGET(data);
-	gchar *text = g_strdup(clip_text);
+	gchar *text = g_utf8_normalize(clip_text, -1, G_NORMALIZE_DEFAULT_COMPOSE);
 	guint *keyvals;
 	gint i;
 	GdkKeymap *keymap = gdk_keymap_get_for_display(gdk_display_get_default());
@@ -636,18 +636,22 @@ void remmina_protocol_widget_send_clip_strokes(GtkClipboard *clipboard, const gc
 				REMMINA_DEBUG("Text clipboard after replacement is \'%s\'", text);
 			}
 			gchar *iter = g_strdup(text);
+			REMMINA_DEBUG("Iter: %s", iter),
 			keyvals = (guint *)g_malloc(strlen(text));
 			while (TRUE) {
 				/* Process each character in the keystrokes */
 				character = g_utf8_get_char_validated(iter, -1);
+				REMMINA_DEBUG("Char: U+%04" G_GINT32_FORMAT"X", character);
 				if (character == 0)
 					break;
 				keyval = gdk_unicode_to_keyval(character);
+				REMMINA_DEBUG("Keyval: %u", keyval);
 				/* Replace all the special character with its keyval */
 				for (i = 0; text_replaces[i].replace; i++) {
 					if (character == text_replaces[i].replace[0]) {
 						keys = g_new0(GdkKeymapKey, 1);
 						keyval = text_replaces[i].keyval;
+						REMMINA_DEBUG("Special Keyval: %u", keyval);
 						/* A special character was generated, no keyval lookup needed */
 						character = 0;
 						break;
@@ -657,7 +661,7 @@ void remmina_protocol_widget_send_clip_strokes(GtkClipboard *clipboard, const gc
 				if (character) {
 					/* get keyval without modifications */
 					if (!gdk_keymap_get_entries_for_keyval(keymap, keyval, &keys, &n_keys)) {
-						g_warning("keyval 0x%04x has no keycode!", keyval);
+						REMMINA_WARNING("keyval 0x%04x has no keycode!", keyval);
 						iter = g_utf8_find_next_char(iter, NULL);
 						continue;
 					}
@@ -1018,14 +1022,13 @@ static gboolean remmina_protocol_widget_tunnel_destroy(RemminaSSHTunnel *tunnel,
 {
 	TRACE_CALL(__func__);
 	RemminaProtocolWidget *gp = REMMINA_PROTOCOL_WIDGET(data);
-	guint idx;
-	gboolean found;
+	guint idx = 0;
 
 #if GLIB_CHECK_VERSION(2, 54, 0)
-	found = g_ptr_array_find(gp->priv->ssh_tunnels, tunnel, &idx);
+	gboolean found = g_ptr_array_find(gp->priv->ssh_tunnels, tunnel, &idx);
 #else
 	int i;
-	found = FALSE;
+	gboolean found = FALSE;
 	for (i = 0; i < gp->priv->ssh_tunnels->len; i++) {
 		if ((RemminaSSHTunnel *)gp->priv->ssh_tunnels->pdata[i] == tunnel) {
 			found = TRUE;
@@ -1057,7 +1060,7 @@ gchar *remmina_protocol_widget_start_direct_tunnel(RemminaProtocolWidget *gp, gi
 	const gchar *server;
 	const gchar *ssh_tunnel_server;
 	gchar *ssh_tunnel_host, *srv_host, *dest;
-	gint srv_port, ssh_tunnel_port;
+	gint srv_port, ssh_tunnel_port = 0;
 
 	REMMINA_DEBUG("SSH tunnel initialization…");
 
@@ -2113,6 +2116,7 @@ void remmina_protocol_widget_send_keys_signals(GtkWidget *widget, const guint *k
 			event.keyval = keyvals[i];
 			event.hardware_keycode = remmina_public_get_keycode_for_keyval(keymap, event.keyval);
 			event.is_modifier = (int)remmina_public_get_modifier_for_keycode(keymap, event.hardware_keycode);
+			REMMINA_DEBUG("Sending keyval: %u, hardware_keycode: %u", event.keyval, event.hardware_keycode);
 			g_signal_emit_by_name(G_OBJECT(widget), "key-press-event", &event, &result);
 		}
 	}
